==> openshift-model-config-6.5.1-sources.jar: io/fabric8/openshift/api/model/config/v1/AuthenticationSpecFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface AuthenticationSpecFluent<A extends AuthenticationSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildOauthMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConfigMapNameReference getOauthMetadata();
  public ConfigMapNameReference buildOauthMetadata();
  public A withOauthMetadata(ConfigMapNameReference oauthMetadata);
  public Boolean hasOauthMetadata();
  public A withNewOauthMetadata(String name);
  public AuthenticationSpecFluent.OauthMetadataNested<A> withNewOauthMetadata();
  public AuthenticationSpecFluent.OauthMetadataNested<A> withNewOauthMetadataLike(ConfigMapNameReference item);
  public AuthenticationSpecFluent.OauthMetadataNested<A> editOauthMetadata();
  public AuthenticationSpecFluent.OauthMetadataNested<A> editOrNewOauthMetadata();
  public AuthenticationSpecFluent.OauthMetadataNested<A> editOrNewOauthMetadataLike(ConfigMapNameReference item);
  public String getServiceAccountIssuer();
  public A withServiceAccountIssuer(String serviceAccountIssuer);
  public Boolean hasServiceAccountIssuer();
  public String getType();
  public A withType(String type);
  public Boolean hasType();
  
  /**
   * This method has been deprecated, please use method buildWebhookTokenAuthenticator instead.
   * @return The buildable object.
   */
  @Deprecated
  public WebhookTokenAuthenticator getWebhookTokenAuthenticator();
  public WebhookTokenAuthenticator buildWebhookTokenAuthenticator();
  public A withWebhookTokenAuthenticator(WebhookTokenAuthenticator webhookTokenAuthenticator);
  public Boolean hasWebhookTokenAuthenticator();
  public AuthenticationSpecFluent.WebhookTokenAuthenticatorNested<A> withNewWebhookTokenAuthenticator();
  public AuthenticationSpecFluent.WebhookTokenAuthenticatorNested<A> withNewWebhookTokenAuthenticatorLike(WebhookTokenAuthenticator item);
  public AuthenticationSpecFluent.WebhookTokenAuthenticatorNested<A> editWebhookTokenAuthenticator();
  public AuthenticationSpecFluent.WebhookTokenAuthenticatorNested<A> editOrNewWebhookTokenAuthenticator();
  public AuthenticationSpecFluent.WebhookTokenAuthenticatorNested<A> editOrNewWebhookTokenAuthenticatorLike(WebhookTokenAuthenticator item);
  public A addToWebhookTokenAuthenticators(Integer index,DeprecatedWebhookTokenAuthenticator item);
  public A setToWebhookTokenAuthenticators(Integer index,DeprecatedWebhookTokenAuthenticator item);
  public A addToWebhookTokenAuthenticators(io.fabric8.openshift.api.model.config.v1.DeprecatedWebhookTokenAuthenticator... items);
  public A addAllToWebhookTokenAuthenticators(Collection<DeprecatedWebhookTokenAuthenticator> items);
  public A removeFromWebhookTokenAuthenticators(io.fabric8.openshift.api.model.config.v1.DeprecatedWebhookTokenAuthenticator... items);
  public A removeAllFromWebhookTokenAuthenticators(Collection<DeprecatedWebhookTokenAuthenticator> items);
  public A removeMatchingFromWebhookTokenAuthenticators(Predicate<DeprecatedWebhookTokenAuthenticatorBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildWebhookTokenAuthenticators instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<DeprecatedWebhookTokenAuthenticator> getWebhookTokenAuthenticators();
  public List<DeprecatedWebhookTokenAuthenticator> buildWebhookTokenAuthenticators();
  public DeprecatedWebhookTokenAuthenticator buildWebhookTokenAuthenticator(Integer index);
  public DeprecatedWebhookTokenAuthenticator buildFirstWebhookTokenAuthenticator();
  public DeprecatedWebhookTokenAuthenticator buildLastWebhookTokenAuthenticator();
  public DeprecatedWebhookTokenAuthenticator buildMatchingWebhookTokenAuthenticator(Predicate<DeprecatedWebhookTokenAuthenticatorBuilder> predicate);
  public Boolean hasMatchingWebhookTokenAuthenticator(Predicate<DeprecatedWebhookTokenAuthenticatorBuilder> predicate);
  public A withWebhookTokenAuthenticators(List<DeprecatedWebhookTokenAuthenticator> webhookTokenAuthenticators);
  public A withWebhookTokenAuthenticators(io.fabric8.openshift.api.model.config.v1.DeprecatedWebhookTokenAuthenticator... webhookTokenAuthenticators);
  public Boolean hasWebhookTokenAuthenticators();
  public AuthenticationSpecFluent.WebhookTokenAuthenticatorsNested<A> addNewWebhookTokenAuthenticator();
  public AuthenticationSpecFluent.WebhookTokenAuthenticatorsNested<A> addNewWebhookTokenAuthenticatorLike(DeprecatedWebhookTokenAuthenticator item);
  public AuthenticationSpecFluent.WebhookTokenAuthenticatorsNested<A> setNewWebhookTokenAuthenticatorLike(Integer index,DeprecatedWebhookTokenAuthenticator item);
  public AuthenticationSpecFluent.WebhookTokenAuthenticatorsNested<A> editWebhookTokenAuthenticator(Integer index);
  public AuthenticationSpecFluent.WebhookTokenAuthenticatorsNested<A> editFirstWebhookTokenAuthenticator();
  public AuthenticationSpecFluent.WebhookTokenAuthenticatorsNested<A> editLastWebhookTokenAuthenticator();
  public AuthenticationSpecFluent.WebhookTokenAuthenticatorsNested<A> editMatchingWebhookTokenAuthenticator(Predicate<DeprecatedWebhookTokenAuthenticatorBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface OauthMetadataNested<N> extends Nested<N>,ConfigMapNameReferenceFluent<AuthenticationSpecFluent.OauthMetadataNested<N>>{
    public N and();
    public N endOauthMetadata();
    
  }
  public interface WebhookTokenAuthenticatorNested<N> extends Nested<N>,WebhookTokenAuthenticatorFluent<AuthenticationSpecFluent.WebhookTokenAuthenticatorNested<N>>{
    public N and();
    public N endWebhookTokenAuthenticator();
    
  }
  public interface WebhookTokenAuthenticatorsNested<N> extends Nested<N>,DeprecatedWebhookTokenAuthenticatorFluent<AuthenticationSpecFluent.WebhookTokenAuthenticatorsNested<N>>{
    public N and();
    public N endWebhookTokenAuthenticator();
    
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/AuthenticationSpecFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface AuthenticationSpecFluent<A extends AuthenticationSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildOauthMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConfigMapNameReference getOauthMetadata();
  public ConfigMapNameReference buildOauthMetadata();
  public A withOauthMetadata(ConfigMapNameReference oauthMetadata);
  public Boolean hasOauthMetadata();
  public A withNewOauthMetadata(String name);
  public AuthenticationSpecFluent.OauthMetadataNested<A> withNewOauthMetadata();
  public AuthenticationSpecFluent.OauthMetadataNested<A> withNewOauthMetadataLike(ConfigMapNameReference item);
  public AuthenticationSpecFluent.OauthMetadataNested<A> editOauthMetadata();
  public AuthenticationSpecFluent.OauthMetadataNested<A> editOrNewOauthMetadata();
  public AuthenticationSpecFluent.OauthMetadataNested<A> editOrNewOauthMetadataLike(ConfigMapNameReference item);
  public String getServiceAccountIssuer();
  public A withServiceAccountIssuer(String serviceAccountIssuer);
  public Boolean hasServiceAccountIssuer();
  public String getType();
  public A withType(String type);
  public Boolean hasType();
  
  /**
   * This method has been deprecated, please use method buildWebhookTokenAuthenticator instead.
   * @return The buildable object.
   */
  @Deprecated
  public WebhookTokenAuthenticator getWebhookTokenAuthenticator();
  public WebhookTokenAuthenticator buildWebhookTokenAuthenticator();
  public A withWebhookTokenAuthenticator(WebhookTokenAuthenticator webhookTokenAuthenticator);
  public Boolean hasWebhookTokenAuthenticator();
  public AuthenticationSpecFluent.WebhookTokenAuthenticatorNested<A> withNewWebhookTokenAuthenticator();
  public AuthenticationSpecFluent.WebhookTokenAuthenticatorNested<A> withNewWebhookTokenAuthenticatorLike(WebhookTokenAuthenticator item);
  public AuthenticationSpecFluent.WebhookTokenAuthenticatorNested<A> editWebhookTokenAuthenticator();
  public AuthenticationSpecFluent.WebhookTokenAuthenticatorNested<A> editOrNewWebhookTokenAuthenticator();
  public AuthenticationSpecFluent.WebhookTokenAuthenticatorNested<A> editOrNewWebhookTokenAuthenticatorLike(WebhookTokenAuthenticator item);
  public A addToWebhookTokenAuthenticators(int index,DeprecatedWebhookTokenAuthenticator item);
  public A setToWebhookTokenAuthenticators(int index,DeprecatedWebhookTokenAuthenticator item);
  public A addToWebhookTokenAuthenticators(io.fabric8.openshift.api.model.config.v1.DeprecatedWebhookTokenAuthenticator... items);
  public A addAllToWebhookTokenAuthenticators(Collection<DeprecatedWebhookTokenAuthenticator> items);
  public A removeFromWebhookTokenAuthenticators(io.fabric8.openshift.api.model.config.v1.DeprecatedWebhookTokenAuthenticator... items);
  public A removeAllFromWebhookTokenAuthenticators(Collection<DeprecatedWebhookTokenAuthenticator> items);
  public A removeMatchingFromWebhookTokenAuthenticators(Predicate<DeprecatedWebhookTokenAuthenticatorBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildWebhookTokenAuthenticators instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<DeprecatedWebhookTokenAuthenticator> getWebhookTokenAuthenticators();
  public List<DeprecatedWebhookTokenAuthenticator> buildWebhookTokenAuthenticators();
  public DeprecatedWebhookTokenAuthenticator buildWebhookTokenAuthenticator(int index);
  public DeprecatedWebhookTokenAuthenticator buildFirstWebhookTokenAuthenticator();
  public DeprecatedWebhookTokenAuthenticator buildLastWebhookTokenAuthenticator();
  public DeprecatedWebhookTokenAuthenticator buildMatchingWebhookTokenAuthenticator(Predicate<DeprecatedWebhookTokenAuthenticatorBuilder> predicate);
  public Boolean hasMatchingWebhookTokenAuthenticator(Predicate<DeprecatedWebhookTokenAuthenticatorBuilder> predicate);
  public A withWebhookTokenAuthenticators(List<DeprecatedWebhookTokenAuthenticator> webhookTokenAuthenticators);
  public A withWebhookTokenAuthenticators(io.fabric8.openshift.api.model.config.v1.DeprecatedWebhookTokenAuthenticator... webhookTokenAuthenticators);
  public Boolean hasWebhookTokenAuthenticators();
  public AuthenticationSpecFluent.WebhookTokenAuthenticatorsNested<A> addNewWebhookTokenAuthenticator();
  public AuthenticationSpecFluent.WebhookTokenAuthenticatorsNested<A> addNewWebhookTokenAuthenticatorLike(DeprecatedWebhookTokenAuthenticator item);
  public AuthenticationSpecFluent.WebhookTokenAuthenticatorsNested<A> setNewWebhookTokenAuthenticatorLike(int index,DeprecatedWebhookTokenAuthenticator item);
  public AuthenticationSpecFluent.WebhookTokenAuthenticatorsNested<A> editWebhookTokenAuthenticator(int index);
  public AuthenticationSpecFluent.WebhookTokenAuthenticatorsNested<A> editFirstWebhookTokenAuthenticator();
  public AuthenticationSpecFluent.WebhookTokenAuthenticatorsNested<A> editLastWebhookTokenAuthenticator();
  public AuthenticationSpecFluent.WebhookTokenAuthenticatorsNested<A> editMatchingWebhookTokenAuthenticator(Predicate<DeprecatedWebhookTokenAuthenticatorBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface OauthMetadataNested<N> extends Nested<N>,ConfigMapNameReferenceFluent<AuthenticationSpecFluent.OauthMetadataNested<N>>{
    public N and();
    public N endOauthMetadata();
    
  }
  public interface WebhookTokenAuthenticatorNested<N> extends Nested<N>,WebhookTokenAuthenticatorFluent<AuthenticationSpecFluent.WebhookTokenAuthenticatorNested<N>>{
    public N and();
    public N endWebhookTokenAuthenticator();
    
  }
  public interface WebhookTokenAuthenticatorsNested<N> extends Nested<N>,DeprecatedWebhookTokenAuthenticatorFluent<AuthenticationSpecFluent.WebhookTokenAuthenticatorsNested<N>>{
    public N and();
    public N endWebhookTokenAuthenticator();
    
  }
  
}
